@@ -37,8 +37,6 @@ class Storage(driver.Base):
             if path.endswith('/'):
                 path = path[:-1]
         return path
-#        if  path:
-#            return path.replace("/", ".")
        
     def content_redirect_url(self, path):
         logger.info("content_redirect_url path:%s" % path)
@@ -46,7 +44,12 @@ class Storage(driver.Base):
         object_instance = self._jss.bucket(self._bucket).object(path1)
         
         return object_instance.generate_url("GET")
-
+    
+    def get_json(self, path):
+        try:
+            return json.loads(self.get_unicode(path) )
+        except:
+            return []
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
